Assess synteny network based on graph properties
Value
A data frame with the following variables:
- CC
Numeric representing clustering coefficient.
- Node_count
Numeric representing number of nodes in the network.
- Rsquared
Numeric indicating the coefficient of determination for the scale-free topology fit.
- Score
Numeric representing network score, which is the product of 'CC' and 'Node_number'.
Details
Network score is the product of the network's clustering coefficient, node count, and R squared for the scale-free topology fit.
Examples
data(synnet)
assess_synnet(synnet)
#> CC Node_count Rsquared Score
#> 1 0.877912 149144 0.6806854 89125.76