R/synteny.R
fit_sft.Rd
Goodness of fit test for the scale-free topology model
fit_sft(edges)
A 2-column data frame with network edges represented in each. Columns 1 and 2 represent nodes 1 and 2 of each edge.
A numeric scalar with the R squared for the scale-free topology fit.
data(synnet) edges <- synnet fit_sft(edges) #> [1] 0.6806854