Get number of shared orthogroups between species pairs
Arguments
- orthogroups
A 3-column data frame with columns Orthogroup, Species, and Gene. This data frame can be created from the 'Orthogroups.tsv' file generated by OrthoFinder with the function
read_orthogroups().
Value
A data frame with the following variables:
- sp1
Character, name of species 1.
- sp2
Character, name of species 2.
- og_overlap
Numeric, number of shared orthogroups.
Examples
path <- system.file("extdata", "Orthogroups.tsv.gz", package = "cogeqc")
orthogroups <- read_orthogroups(path)
ov_df <- get_og_overlap(orthogroups)